@@ -1,7 +1,7 @@
 package Log::ger::App;
 
 our $DATE = '2020-11-11'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -185,8 +185,14 @@ sub import {
     }
 
     if (my $outputs = delete $args{outputs}) {
-        $conf{outputs}{$_} = $outputs->{$_}
-            for keys %{$outputs->{$_}};
+        for my $o (sort keys %$outputs) {
+            if ($conf{outputs}{$o}) {
+                warn "[lga] OVERWRITING output '$o' using output from 'outputs' argument\n" if $DEBUG;
+            } else {
+                warn "[lga] Adding output '$o' from 'outputs' argument\n" if $DEBUG;
+            }
+            $conf{outputs}{$o} = $outputs->{$o};
+        }
     }
 
     die "Unknown argument(s): ".join(", ", sort keys %args)
@@ -214,7 +220,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
